@@ -177,7 +177,7 @@ c
       cas = index(gen, 'em') .gt. 0 
       obas = index(gen, 'as') .gt. 0 .or.
      *   index(gen, 'lat') .gt. 0
-!
+
       if(obas ) then
 c          energy / nucleon for heavy
          if(IncidentCopy.p.code .ge. kdeut .and.
@@ -192,23 +192,21 @@ c          energy / nucleon for heavy
                ! generation. WaitRatio < 1 should be used when 1ry is 
                ! g or e.   (say, 0.01)
          EasWait =ergpn * WaitRatio
-         EminAS=min(ergpn*RatioToE0, EasWait) ! follow at least down to  this
-c                                    energy for hadronic interaction
-      else
-         EminAS = 1.d30
       endif
 
-      emin = eminob
+
       emCas = 1.d30
 
       if(obas) then
-	  emin = min(EminAS, emin)   
-          emCas =min(eminob, EasWait)
+         emCas = EasWait
       endif
       if(cas) then
-         emCas =min(emin, EminAS)
+         emCas =min(eminob, emCas)
       endif
-
+      emin = eminob
+      if(obas) then
+         emin = min(emin, max(RatioToE0* ergpn, 1.d0) )
+      endif 
 
       if(ThinSampling) then
 c           thin sampling
